==> owncloud-10.0.4.zip: owncloud/settings/l10n/sr@latin.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "Greška pri autentifikaciji",
    "Couldn't send reset email. Please contact your administrator." : "Nemoguće slanje e-mail-a za ponovno postavljanje lozinke. Molimo Vas kontaktirajte Vašeg administratora",
    "Saved" : "Sačuvano",
    "Email sent" : "Email poslat",
    "Language changed" : "Jezik je izmenjen",
    "Invalid request" : "Neispravan zahtev",
    "Delete" : "Obriši",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Osrednja lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Groups" : "Grupe",
    "never" : "nikad",
    "Cheers!" : "U zdravlje!",
    "Port" : "Port",
    "Get the apps to sync your files" : "Preuzmite aplikacije za sinhronizaciju Vaših fajlova",
    "Desktop client" : "Desktop klijent",
    "Android app" : "Android aplikacija",
    "iOS app" : "iOS aplikacija",
    "Cancel" : "Otkaži",
    "Email" : "E-mail",
    "Password" : "Lozinka",
    "Unable to change your password" : "Ne mogu da izmenim vašu lozinku",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Izmeni lozinku",
    "Language" : "Jezik",
    "Name" : "naziv",
    "Username" : "Korisničko ime",
    "Personal" : "Lično",
    "Admin" : "Adninistracija",
    "Error" : "Greška",
    "Create" : "Napravi",
    "Group" : "Grupa",
    "Other" : "Drugo"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.4.0.zip: owncloud/settings/l10n/sr@latin.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "Greška pri autentifikaciji",
    "Couldn't send reset email. Please contact your administrator." : "Nemoguće slanje e-mail-a za ponovno postavljanje lozinke. Molimo Vas kontaktirajte Vašeg administratora",
    "Saved" : "Sačuvano",
    "Email sent" : "Email poslat",
    "Create" : "Napravi",
    "Delete" : "Obriši",
    "Share" : "Deljenje",
    "Language changed" : "Jezik je izmenjen",
    "Invalid request" : "Neispravan zahtev",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Osrednja lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Groups" : "Grupe",
    "never" : "nikada",
    "Cheers!" : "U zdravlje!",
    "Language" : "Jezik",
    "Port" : "Port",
    "Get the apps to sync your files" : "Preuzmite aplikacije za sinhronizaciju Vaših fajlova",
    "Desktop client" : "Desktop klijent",
    "Android app" : "Android aplikacija",
    "iOS app" : "iOS aplikacija",
    "Add" : "Dodaj",
    "Cancel" : "Otkaži",
    "Email" : "E-mail",
    "Password" : "Lozinka",
    "Unable to change your password" : "Ne mogu da izmenim vašu lozinku",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Izmeni lozinku",
    "Name" : "naziv",
    "Username" : "Korisničko ime",
    "New Password" : "Nova lozinka",
    "Personal" : "Lično",
    "Admin" : "Adninistracija",
    "Other" : "Drugo",
    "Settings" : "Podešavanja",
    "Group" : "Grupa"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
